{% if version.major | int < 6 %}
usr/bin/slurm-web-agent usr/libexec/slurm-web
usr/bin/slurm-web-coonect-check usr/libexec/slurm-web
{% endif %}
conf/vendor/agent.yml usr/share/slurm-web/conf
conf/vendor/policy.* usr/share/slurm-web/conf
lib/systemd/slurm-web-agent.service lib/systemd/system
lib/wsgi/agent usr/share/slurm-web/wsgi
