#!/usr/bin/make -f

# Avoid pybuild automatic test arguments 'tests' in presence of tests/ folder
# which restricts tests discovery in this folder which only contains assets in
# Slurm-web.
export PYBUILD_TEST_ARGS=

%:
	dh $@ --with python3 --buildsystem=pybuild

override_dh_auto_build:
	dh_auto_build
	docs/update-materials man
	npm --prefix=frontend run build

override_dh_installsystemd:
	dh_installsystemd --no-start --no-enable --name slurm-web-agent
	dh_installsystemd --no-start --no-enable --name slurm-web-gateway

# Can be dropped in compat level 14
execute_after_dh_installinit:
	dh_installsysusers
