Source: slurm-web
Section: utils
Priority: optional
Maintainer: HPCKit team <maintainers@hpck.it>
Homepage: https://github.com/rackslab/slurm-web
Build-Depends:
 debhelper-compat (= 13),
 python3-all (>= 3.6),
 python3-setuptools,
 pybuild-plugin-pyproject,
 dh-exec,
 dh-python,
 asciidoctor,
 npm,
 python3-aiohttp,
 python3-flask,
 python3-flask-cors,
 python3-ldap,
 python3-markdown,
{% if version.major | int > 4 %}
 python3-parameterized,
{% endif %}
 python3-prometheus-client,
 python3-pytest,
 python3-racksdb-web,
 python3-redis,
 python3-requests,
 python3-rfl-build,
 python3-rfl-authentication,
 python3-rfl-log,
 python3-rfl-settings,
 python3-rfl-web,
Standards-Version: 4.2.1

Package: python3-slurm-web
Architecture: all
Section: python
Depends:
 ${misc:Depends},
 ${python3:Depends},
Description: Web interface for Slurm HPC workload manager: common library
 This software provides a web interface to monitor and manage an HPC cluster
 running Slurm workload manager.
 This package contains the common Python library used by all Slurm-web
 components.

Package: slurm-web-gateway
Architecture: all
Section: utils
Depends:
 ${misc:Depends},
 ${python3:Depends},
 python3-slurm-web (= ${binary:Version}),
 python3-markdown,
{% if version.major | int < 5 %}
 python3-aiohttp,
{% endif %}
 acl,
Description: Web interface for Slurm HPC workload manager: gateway component
 This software provides a web interface to monitor and manage an HPC cluster
 running Slurm workload manager.
 This package contains the gateway backend component and the frontend
 application.

Package: slurm-web-agent
Architecture: all
Section: utils
Depends:
 ${misc:Depends},
 ${python3:Depends},
 python3-slurm-web (= ${binary:Version}),
 python3-prometheus-client,
 python3-racksdb-web,
 python3-redis,
 python3-requests,
Suggests:
 racksdb,
 redis-server,
 slurmrestd,
Description: Web interface for Slurm HPC workload manager: agent component
 This software provides a web interface to monitor and manage an HPC cluster
 running Slurm workload manager.
 This package contains the agent component to deploy on all clusters.
