{% if version.major | int > 5 %}
usr/libexec/slurm-web/slurm-web-compat usr/libexec/slurm-web/slurm-web-agent
usr/libexec/slurm-web/slurm-web-compat usr/libexec/slurm-web/slurm-web-connect-check
{% endif %}
